@@ -5,7 +5,7 @@ import math
 from pygalaxy import ConvertMaster
 from PIL import Image, ImageDraw, ImageFont
 from .PsdParseInfo import PsdParseInfo
-from . import logger
+from pygalaxy import logger
 
 
 def get_right_triangle_side(hypotenuse):
@@ -312,6 +312,7 @@ class ImgCompounder:
         self.__drawCameraBorderText()
         self.__drawCameraBorderLogo()
         self.__drawCameraLens()
+        self.__delete_temp_files()
         compound_result_data = {
             'fileName': '%s.png' % self.compound_file_name,
             'path': self.compound_file_path,
@@ -959,6 +960,19 @@ class ImgCompounder:
             logger.error('[*] 摄像头镜头绘制错误: %s' % repr(e))
             logger.error('[*]')
 
+    def __delete_temp_files(self):
+        try:
+            if not self.psd_parse_info.temp_file_path_list or len(self.psd_parse_info.temp_file_path_list) <= 0:
+                return
+            for path in self.psd_parse_info.temp_file_path_list:
+                if os.path.exists(path):
+                    os.remove(path)
+        except Exception as e:
+            logger.error('[*] 临时文件删除出错: %s' % repr(e))
+            logger.info('[*]')
+            return None
+
+
     def __to_cmyk(self):
         with Image.open(self.compound_file_path) as compound_img:
             compound_img = compound_img.convert('CMYK')
