@@ -4,7 +4,7 @@ import os
 from PIL import Image
 from psd_tools import PSDImage
 from psd_tools.constants import ColorMode
-from . import logger
+from pygalaxy import logger
 from .PsdParseInfo import PsdParseInfo
 
 
@@ -89,6 +89,7 @@ class PsdParser:
             self.psd_parse_info.main_img_height = layer.height
             layer_image = layer.composite()
             layer_image.save(main_img_save_path)
+            self.psd_parse_info.temp_file_path_list.append(main_img_save_path)
             logger.info("[*] 主图层解析后获取的图片存储在: %s" % main_img_save_path)
             logger.info("[*] 主图层解析成功完成")
             logger.info("[*] ")
@@ -109,6 +110,7 @@ class PsdParser:
             main_border_color = main_border_img.getpixel((int(main_border_img.width / 2), 2))
             main_border_color = rgb_to_hex(main_border_color)
             self.psd_parse_info.main_border_color = main_border_color
+            self.psd_parse_info.temp_file_path_list.append(main_border_img_save_path)
             logger.info("[*] 主边框图层颜色: %s" % main_border_color)
             logger.info("[*] 主边框图层解析成功完成")
             logger.info("[*] ")
@@ -158,6 +160,7 @@ class PsdParser:
                 color = main_border_gradient_img.getpixel(coordinate)
                 color = rgb_to_hex(color)
                 self.psd_parse_info.main_border_gradient_colors.append(color)
+            self.psd_parse_info.temp_file_path_list.append(main_border_gradient_img_save_path)
             logger.info("[*] 主边框渐变图层颜色: %s" % self.psd_parse_info.main_border_gradient_colors.__str__())
             logger.info("[*] 主边框渐变图层解析成功完成")
             logger.info("[*] ")
@@ -192,6 +195,7 @@ class PsdParser:
             self.psd_parse_info.main_border_logo_height = layer.height
             layer_image = layer.composite()
             layer_image.save(main_border_logo_save_path)
+            self.psd_parse_info.temp_file_path_list.append(main_border_logo_save_path)
             logger.info("[*] 主边框logo图层解析后获取的图片存储在: %s" % main_border_logo_save_path)
             logger.info("[*] 主边框logo图层解析成功完成")
             logger.info("[*] ")
@@ -212,6 +216,7 @@ class PsdParser:
             camera_border_color = camera_border_img.getpixel((int(camera_border_img.width / 2), 2))
             camera_border_color = rgb_to_hex(camera_border_color)
             self.psd_parse_info.camera_border_color = camera_border_color
+            self.psd_parse_info.temp_file_path_list.append(camera_border_img_save_path)
             logger.info("[*] 摄像头边框图层颜色: %s" % camera_border_color)
             logger.info("[*] 摄像头边框图层解析成功完成")
             logger.info("[*] ")
@@ -263,6 +268,7 @@ class PsdParser:
                 color = camera_border_gradient_img.getpixel(coordinate)
                 color = rgb_to_hex(color)
                 self.psd_parse_info.camera_border_gradient_colors.append(color)
+            self.psd_parse_info.temp_file_path_list.append(camera_border_gradient_img_save_path)
             logger.info("[*] 摄像头边框渐变图层颜色: %s" % self.psd_parse_info.camera_border_gradient_colors.__str__())
             logger.info("[*] 摄像头边框渐变图层解析成功完成")
             logger.info("[*] ")
@@ -298,6 +304,7 @@ class PsdParser:
             self.psd_parse_info.camera_border_logo_height = layer.height
             layer_image = layer.composite()
             layer_image.save(camera_border_logo_save_path)
+            self.psd_parse_info.temp_file_path_list.append(camera_border_logo_save_path)
             logger.info("[*] 摄像头边框logo图层解析后获取的图片存储在: %s" % camera_border_logo_save_path)
             logger.info("[*] 摄像头边框logo图层解析成功完成")
             logger.info("[*] ")
@@ -318,6 +325,7 @@ class PsdParser:
             camera_lens_color = camera_lens_img\
                 .getpixel((int(camera_lens_img.width / 2), int(camera_lens_img.height / 2)))
             camera_lens_color = rgb_to_hex(camera_lens_color)
+            self.psd_parse_info.temp_file_path_list.append(camera_lens_img_save_path)
             logger.info("[*] 摄像头镜头图层%s颜色: %s" % (layer.name, camera_lens_color))
             logger.info("[*] 摄像头镜头图层解析成功完成")
             logger.info("[*] ")
